/* ----------------------------------------
Code exported from SAS Enterprise Guide
DATE: Wednesday, February 20, 2008     TIME: 5:27:59 PM
PROJECT: Graph Examples 200802
PROJECT PATH: C:\Documents and Settings\Stephen\My Documents\EG Samples\Graph Examples 200802.egp
---------------------------------------- */


/* Conditionally delete a table or view, if it exists          */
/* If the member does not exist, then no action is performed   */
%macro _eg_conditional_dropds(dsname);
	%IF %SYSFUNC(EXIST(&dsname)) %THEN %DO;
		PROC SQL;
			DROP TABLE &dsname;
		QUIT;
	%END;
	%IF %SYSFUNC(EXIST(&dsname,VIEW)) %THEN %DO;
		PROC SQL;
			DROP VIEW &dsname;
		QUIT;
	%END;
%mend _eg_conditional_dropds;

%macro _eg_inParam( PARM=, TYPE=S );
  %local q;
  %if %QUPCASE(&TYPE) eq S or %QUPCASE(&TYPE) eq STRING %then
    %let q=%str(%");
  %else
    %let q=;
  
  %local z;
  %let z=0;
  %if not %symexist(&PARM) %then %do;
    ""
  %end;
  %else %if not %symexist(&PARM&z) or "&&&PARM&Z" = "" %then %do;
    %if "&&&PARM" = "" and "&TYPE" = "N" %then %do; . %end;
    %else %do;
      %unquote(&q)&&&PARM%unquote(&q)
    %end;
  %end;
  %else %do;
     %do i=1 %to &&&PARM&z; %if &i > 1 %then %do; , %end; 
       %unquote(&q)&&&PARM&i%unquote(&q) %end; 
  %end;
%mend;

/* ---------------------------------- */
/* MACRO: enterpriseguide             */
/* PURPOSE: define a macro variable   */
/*   that contains the file system    */
/*   path of the WORK library on the  */
/*   server.  Note that different     */
/*   logic is needed depending on the */
/*   server type.                     */
/* ---------------------------------- */
%macro enterpriseguide;
%global sasworklocation;
%if &sysscp=OS %then %do; /* MVS Server */
	%if %sysfunc(getoption(filesystem))=MVS %then %do;
        /* By default, physical file name will be considered a classic MVS data set. */
	    /* Construct dsn that will be unique for each concurrent session under a particular account: */
		filename egtemp '&egtemp' disp=(new,delete); /* create a temporary data set */
 		%let tempdsn=%sysfunc(pathname(egtemp)); /* get dsn */
		filename egtemp clear; /* get rid of data set - we only wanted its name */
		%let unique_dsn=".EGTEMP.%substr(&tempdsn, 1, 16).PDSE"; 
		filename egtmpdir &unique_dsn
			disp=(new,delete,delete) space=(cyl,(5,5,50))
			dsorg=po dsntype=library recfm=vb
			lrecl=8000 blksize=8004 ;
		options fileext=ignore ;
	%end; 
 	%else %do; 
        /* 
		By default, physical file name will be considered an HFS 
		(hierarchical file system) file. 
		Note:  This does NOT support users who do not have an HFS home directory.
		It also may not support multiple simultaneous sessions under the same account.
		*/
		filename egtmpdir './';                          
	%end; 
	%let path=%sysfunc(pathname(egtmpdir));
        %let sasworklocation=%sysfunc(quote(&path));  
%end; /* MVS Server */
%else %do;
	%let sasworklocation = "%sysfunc(getoption(work))/";
%end;
%if &sysscp=VMS_AXP %then %do; /* Alpha VMS server */
	%let sasworklocation = "%sysfunc(getoption(work))";                         
%end;
%if &sysscp=CMS %then %do; 
	%let path = %sysfunc(getoption(work));                         
	%let sasworklocation = "%substr(&path, %index(&path,%str( )))";
%end;
%mend enterpriseguide;

%enterpriseguide

ODS PROCTITLE;
OPTIONS DEV=ACTXIMG;
GOPTIONS XPIXELS=800 YPIXELS=600;
FILENAME EGRTFX TEMP;
ODS RTF(ID=EGRTFX) FILE=EGRTFX ENCODING='wlatin1' STYLE=Rtf NOGTITLE NOGFOOTNOTE;

/*   START OF NODE: Query for CANDY_SALES_SUMMARY   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Query for CANDY_SALES_SUMMARY);
%LET _EGTASKLABEL=%NRBQUOTE(Query for CANDY_SALES_SUMMARY);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%_eg_conditional_dropds(SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003);

PROC SQL;
 CREATE TABLE SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003 AS SELECT CANDY_SALES_SUMMARY.Name,
	 CANDY_SALES_SUMMARY.Region,
	 CANDY_SALES_SUMMARY.OrderID,
	 CANDY_SALES_SUMMARY.ProdID,
	 CANDY_SALES_SUMMARY.Customer,
	 CANDY_SALES_SUMMARY.Type,
	 CANDY_SALES_SUMMARY.Product,
	 CANDY_SALES_SUMMARY.Category,
	 CANDY_SALES_SUMMARY.Subcategory,
	 CANDY_SALES_SUMMARY.Retail_Price FORMAT=DOLLAR10.2,
	 CANDY_SALES_SUMMARY.Units,
	 CANDY_SALES_SUMMARY.Discount,
	 CANDY_SALES_SUMMARY.Date FORMAT=MMDDYY10.,
	 CANDY_SALES_SUMMARY.Fiscal_Year,
	 CANDY_SALES_SUMMARY.Fiscal_Quarter,
	 CANDY_SALES_SUMMARY.Fiscal_Month_Num,
	 CANDY_SALES_SUMMARY.Sale_Amount FORMAT=DOLLAR9.2,
	 (INPUT(CANDY_SALES_SUMMARY.Discount ,
	percent8.1)*10) FORMAT=PERCENTN8.1 label="Customer Discount" AS Customer_Discount 
 FROM EGSAMPLE.CANDY_SALES_SUMMARY AS CANDY_SALES_SUMMARY
 WHERE CANDY_SALES_SUMMARY.Fiscal_Year IN ("2000", "2001", "2002", "2003");
QUIT;




%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Bar Chart   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Bar Chart);
%LET _EGTASKLABEL=%NRBQUOTE(Bar Chart);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%macro _SASTASK_DROPDS(dsname);
	%IF %SYSFUNC(EXIST(&dsname)) %THEN %DO;
		DROP TABLE &dsname;
	%END;
	%IF %SYSFUNC(EXIST(&dsname, VIEW)) %THEN %DO;
		DROP VIEW &dsname;
	%END;
%mend _SASTASK_DROPDS;

%LET _EGCHARTWIDTH=800;
%LET _EGCHARTHEIGHT=600;
/* -------------------------------------------------------------------
   Code generated by SAS Task

   Generated on: Wednesday, February 20, 2008 at 5:24:49 PM
   By task: Bar Chart

   Input Data: SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003
   Server:  Local
   ------------------------------------------------------------------- */

PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

/* -------------------------------------------------------------------
   Data set SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003 does not need to be sorted.
   ------------------------------------------------------------------- */
PROC SQL;
	CREATE VIEW WORK.SORTTempTableSorted
		AS SELECT Fiscal_Quarter, Category, Sale_Amount FROM SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003;
QUIT;
GOPTIONS xpixels=&_EGCHARTWIDTH ypixels=&_EGCHARTHEIGHT;
	GOPTIONS COLORS = (CX94B7DA , CXB6D2A2 , CXDCC685 , CX9089AD , CXB6D8EA , CXD2D2C1 , CXA86B86 , CX61A1A3 , CXA89D74 , CXB4BDD8 , CXEEEAC1 , CX91A2A9);

Axis1
	STYLE=1
	WIDTH=1
	LABEL=( "Sales" )


;
Axis2
	STYLE=1
	WIDTH=1
	MINOR=NONE


;
Axis3

;
Axis3
	STYLE=1
	WIDTH=1


;
TITLE;
TITLE1 "Total and Average Sales by Product Category";
FOOTNOTE;
FOOTNOTE1 "Generated by the SAS System (&_SASSERVERNAME, &SYSSCPL) on %SYSFUNC(DATE(), EURDFDE9.) at %SYSFUNC(TIME(), TIMEAMPM8.)";
PROC GCHART DATA=WORK.SORTTempTableSorted
;
	HBAR	 Fiscal_Quarter
 /
	SUMVAR=Sale_Amount
	GROUP=Category
	CLIPREF
FRAME	DISCRETE
	TYPE=SUM
	MEAN
	COUTLINE=BLACK
	MAXIS=AXIS1
	RAXIS=AXIS2
	GAXIS=AXIS3
	GAXIS=AXIS3
PATTERNID=GROUP
;
	FORMAT 
		Sale_Amount DOLLAR15.0;
/* -------------------------------------------------------------------
   End of task code.
   ------------------------------------------------------------------- */
RUN; QUIT;
PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

TITLE; FOOTNOTE;
GOPTIONS RESET=ALL;



%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Export File   */

/*   START OF NODE: Query for QUERY_FOR_CANDY_SALES_SUMMA_0003   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Query for QUERY_FOR_CANDY_SALES_SUMMA_0003);
%LET _EGTASKLABEL=%NRBQUOTE(Query for QUERY_FOR_CANDY_SALES_SUMMA_0003);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%_eg_conditional_dropds(SASUSER.QUERY_FOR_QUERY_FOR_CANDY_S_0000);

PROC SQL;
 CREATE TABLE SASUSER.QUERY_FOR_QUERY_FOR_CANDY_S_0000 AS SELECT QUERY_FOR_CANDY_SALES_SUMMA_00.Subcategory,
	 (SUM(QUERY_FOR_CANDY_SALES_SUMMA_00.Sale_Amount)) FORMAT=DOLLAR15.0 label="Total Sale Amount" AS SUM_OF_Sale_Amount,
	 (AVG(QUERY_FOR_CANDY_SALES_SUMMA_00.Retail_Price)) FORMAT=DOLLAR10.2 label="Average Retail Price" AS AVG_OF_Retail_Price 
 FROM SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003 AS QUERY_FOR_CANDY_SALES_SUMMA_00
 GROUP BY QUERY_FOR_CANDY_SALES_SUMMA_00.Subcategory;
QUIT;




%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Bubble Plot   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Bubble Plot);
%LET _EGTASKLABEL=%NRBQUOTE(Bubble Plot);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%macro _SASTASK_DROPDS(dsname);
	%IF %SYSFUNC(EXIST(&dsname)) %THEN %DO;
		DROP TABLE &dsname;
	%END;
	%IF %SYSFUNC(EXIST(&dsname, VIEW)) %THEN %DO;
		DROP VIEW &dsname;
	%END;
%mend _SASTASK_DROPDS;

%LET _EGCHARTWIDTH=800;
%LET _EGCHARTHEIGHT=600;
/* -------------------------------------------------------------------
   Code generated by SAS Task

   Generated on: Wednesday, February 20, 2008 at 5:25:06 PM
   By task: Bubble Plot

   Input Data: SASUSER.QUERY_FOR_QUERY_FOR_CANDY_S_0000
   Server:  Local
   ------------------------------------------------------------------- */

PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

/* -------------------------------------------------------------------
   Data set SASUSER.QUERY_FOR_QUERY_FOR_CANDY_S_0000 does not need to be sorted.
   ------------------------------------------------------------------- */
PROC SQL;
	CREATE VIEW WORK.SORTTempTableSorted
		AS SELECT Subcategory, SUM_OF_Sale_Amount, AVG_OF_Retail_Price FROM SASUSER.QUERY_FOR_QUERY_FOR_CANDY_S_0000;
QUIT;
GOPTIONS xpixels=&_EGCHARTWIDTH ypixels=&_EGCHARTHEIGHT;
Axis1
	STYLE=1
	WIDTH=1
	ORDER=(0 TO 30000000 BY 5000000)	MINOR=NONE


;
Axis2
	STYLE=1
	WIDTH=1
	MINOR=NONE


;
TITLE;
TITLE1 "Bubble Plot- Total Sales and Average Retail Price by Subcategory";
FOOTNOTE;
FOOTNOTE1 "Generated by the SAS System (&_SASSERVERNAME, &SYSSCPL) on %SYSFUNC(DATE(), EURDFDE9.) at %SYSFUNC(TIME(), TIMEAMPM8.)";
PROC GPLOT DATA = WORK.SORTTempTableSorted
	UNIFORM
;
	BUBBLE SUM_OF_Sale_Amount	* Subcategory	= AVG_OF_Retail_Price
 / 
	VAXIS=AXIS1

	HAXIS=AXIS2

	BLABEL
	BSIZE=14FRAME;
;
/* -------------------------------------------------------------------
   End of task code.
   ------------------------------------------------------------------- */
RUN; QUIT;
PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

TITLE; FOOTNOTE;
GOPTIONS RESET=ALL;



%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Export File   */

/*   START OF NODE: Box Plot   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Box Plot);
%LET _EGTASKLABEL=%NRBQUOTE(Box Plot);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%macro _SASTASK_DROPDS(dsname);
	%IF %SYSFUNC(EXIST(&dsname)) %THEN %DO;
		DROP TABLE &dsname;
	%END;
	%IF %SYSFUNC(EXIST(&dsname, VIEW)) %THEN %DO;
		DROP VIEW &dsname;
	%END;
%mend _SASTASK_DROPDS;

%LET _EGCHARTWIDTH=800;
%LET _EGCHARTHEIGHT=600;
/* -------------------------------------------------------------------
   Code generated by SAS Task

   Generated on: Wednesday, February 20, 2008 at 5:24:53 PM
   By task: Box Plot

   Input Data: SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003
   Server:  Local
   ------------------------------------------------------------------- */

PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

/* -------------------------------------------------------------------
   Data set SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003 does not need to be sorted.
   ------------------------------------------------------------------- */
PROC SQL;
	CREATE VIEW WORK.SORTTempTableSorted
		AS SELECT Subcategory, Retail_Price FROM SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003;
QUIT;
GOPTIONS xpixels=&_EGCHARTWIDTH ypixels=&_EGCHARTHEIGHT;
	SYMBOL1 INTERPOL=BOXF	CV=CXEDEFED
	CO=BLACK
	VALUE=POINT
	HEIGHT=3
;
Axis1
	STYLE=1
	WIDTH=1
	MINOR=NONE

;
Axis2
	STYLE=1
	WIDTH=1
	MINOR=NONE

;
TITLE;
TITLE1 "Box Plot- Average Retail Sales Price by Subcategory";
FOOTNOTE;
FOOTNOTE1 "Generated by the SAS System (&_SASSERVERNAME, &SYSSCPL) on %SYSFUNC(DATE(), EURDFDE9.) at %SYSFUNC(TIME(), TIMEAMPM8.)";
PROC GPLOT DATA=WORK.SORTTempTableSorted
;
	PLOT Retail_Price * Subcategory/
	VAXIS=AXIS1

	HAXIS=AXIS2

;
/* -------------------------------------------------------------------
   End of task code.
   ------------------------------------------------------------------- */
RUN; QUIT;
PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

TITLE; FOOTNOTE;
GOPTIONS RESET=ALL;



%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Export File   */

/*   START OF NODE: Scatter Plot   */
%LET _CLIENTTASKLABEL=%NRBQUOTE(Scatter Plot);
%LET _EGTASKLABEL=%NRBQUOTE(Scatter Plot);
%LET _CLIENTPROJECTNAME=%NRBQUOTE(C:\Documents and Settings\Stephen\My Documents\Graph Examples 200802.egp);

%macro _SASTASK_DROPDS(dsname);
	%IF %SYSFUNC(EXIST(&dsname)) %THEN %DO;
		DROP TABLE &dsname;
	%END;
	%IF %SYSFUNC(EXIST(&dsname, VIEW)) %THEN %DO;
		DROP VIEW &dsname;
	%END;
%mend _SASTASK_DROPDS;

%LET _EGCHARTWIDTH=800;
%LET _EGCHARTHEIGHT=600;
/* -------------------------------------------------------------------
   Code generated by SAS Task

   Generated on: Wednesday, February 20, 2008 at 5:24:57 PM
   By task: Scatter Plot

   Input Data: SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003
   Server:  Local
   ------------------------------------------------------------------- */

PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

/* -------------------------------------------------------------------
   Data set SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003 does not need to be sorted.
   ------------------------------------------------------------------- */
PROC SQL;
	CREATE VIEW WORK.SORTTempTableSorted
		AS SELECT Sale_Amount, Customer_Discount FROM SASUSER.QUERY_FOR_CANDY_SALES_SUMMA_0003;
QUIT;
GOPTIONS xpixels=&_EGCHARTWIDTH ypixels=&_EGCHARTHEIGHT;
	SYMBOL1
	INTERPOL=NONE
	HEIGHT=2pt
	VALUE=DIAMOND
	CV=BLUE
	LINE=1
	WIDTH=2
	;
Axis1
	STYLE=1
	WIDTH=1
	MINOR=NONE


;
Axis2
	STYLE=1
	WIDTH=1
	MINOR=NONE
	LABEL=( "Sale Amount" )


;
TITLE;
TITLE1 "Scatter Plot of Discount Granted by Sale Amount";
FOOTNOTE;
FOOTNOTE1 "Generated by the SAS System (&_SASSERVERNAME, &SYSSCPL) on %SYSFUNC(DATE(), EURDFDE9.) at %SYSFUNC(TIME(), TIMEAMPM8.)";
PROC GPLOT DATA=WORK.SORTTempTableSorted
;
PLOT Customer_Discount * Sale_Amount / 
	VAXIS=AXIS1

	HAXIS=AXIS2

FRAME ;
	FORMAT Sale_Amount DOLLAR9.0
		Customer_Discount PERCENTN8.0;
/* -------------------------------------------------------------------
   End of task code.
   ------------------------------------------------------------------- */
RUN; QUIT;
PROC SQL;
%_SASTASK_DROPDS(WORK.SORTTempTableSorted);
QUIT;

TITLE; FOOTNOTE;
GOPTIONS RESET=ALL;



%LET _CLIENTTASKLABEL=;
%LET _EGTASKLABEL=;
%LET _CLIENTPROJECTNAME=;


/*   START OF NODE: Export File   */
;*';*";*/;quit;run;
ODS _ALL_ CLOSE;
